rse.main package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   rse.main.config
   rse.main.database
   rse.main.parsers

Submodules
----------

rse.main.criteria module
------------------------

.. automodule:: rse.main.criteria
   :members:
   :undoc-members:
   :show-inheritance:

rse.main.taxonomy module
------------------------

.. automodule:: rse.main.taxonomy
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: rse.main
   :members:
   :undoc-members:
   :show-inheritance:
